@@ -1,13 +1,14 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:31:36
-# @Last Modified time: 2020-06-17 21:08:23
+# @Last Modified time: 2020-11-30 18:17:17
 # @github: https://github.com/longfengpili
 
-#!/usr/bin/env python3
+# !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
 from .parse import SqlParse, SqlFileParse
 from .compile import SqlCompile
+from .colmodel import ColumnModel, ColumnsModel
 
-__all__ = ['SqlParse', 'SqlCompile', 'SqlFileParse']
+__all__ = ['SqlParse', 'SqlCompile', 'SqlFileParse', 'ColumnModel', 'ColumnsModel']
